#========================================================================================
# package      DE_EPAGES::AmazonPayments::t::unit::ui::UI_OrderProcess
# base         DE_EPAGES::Core::API::Test
#----------------------------------------------------------------------------------------
# description  Unit test for ExecutePayment::Service
#========================================================================================
package DE_EPAGES::AmazonPayments::t::unit::ui::OrderProcess;
use base DE_EPAGES::Core::API::Test;
use Test::More;
use DE_EPAGES::Test::Mock::Mockify qw (GetParametersFromMockifyCall);
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use DE_EPAGES::Test::Mock::MockifyServlet;
use DE_EPAGES::Test::Mock::EpagesObject;
use Test::Mockify::Sut;
use Test::Mockify::Matcher qw ( Object HashRef );
use strict;

use constant SUCCESS_URL => 'https://www.google.com/?q=success';
use constant FAILURE_URL => 'https://www.google.com/?q=error';

sub test {
    my $self = shift;

    $self->test_orderConfirmation_callbackurls_are_correct();

    done_testing();
}

sub test_orderConfirmation_callbackurls_are_correct {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $LineItemPayment = $self->_createLineItemPayment({});
    my $LineItemContainer = $self->_createLineItemContainer({
        'Payment' => $LineItemPayment,
    });
    my $Basket = $self->_createBasket({'LineItemContainer' => $LineItemContainer});
    my $Servlet = $self->_createServlet($Basket);

    my $SUT = $self->_createSUT();

    $SUT->OrderConfirmationAmazonPayment($Servlet);

    my $aConfirmOrderParameters = GetParametersFromMockifyCall($LineItemPayment , 'confirmOrder');
    my $aExpectedParameters = [SUCCESS_URL, FAILURE_URL];

    is_deeply($aConfirmOrderParameters, $aExpectedParameters, "$SubTestName - Test if SuccessUrl and FailureUrl are correctly setup");

}

#----------------------------------------------------------------------------------------
# helpers
#----------------------------------------------------------------------------------------
sub _createSUT {
    my $self = shift;

    my $MockifySut = Test::Mockify::Sut->new(
                   'DE_EPAGES::AmazonPayments::UI::OrderProcess',
                   []
    );

    my $hCallbackUrlOptions = {
        'Type' => 'sf/mobile',
        'AddToken' => '1',
        'UseSSL' => '1',
    };
    my $hSuccessUrlParams = {
        'ChangeAction' => 'SaveMultiCheckoutConfirmation',
    };
    $MockifySut->mockImported('DE_EPAGES::Shop::API::Url', 'BuildShopUrl')
                ->when(Object('DE_EPAGES::Order::API::Object::Basket'), HashRef($hSuccessUrlParams), HashRef($hCallbackUrlOptions), Object('DE_EPAGES::Presentation::Servlet::Permission'))
                ->thenReturn(SUCCESS_URL);

    my $hFailureUrlParams = {
        'ViewAction' => 'ViewMultiCheckoutAmazonPayment',
    };
    $MockifySut->mockImported('DE_EPAGES::Shop::API::Url', 'BuildShopUrl')
                ->when(Object('DE_EPAGES::Order::API::Object::Basket'), HashRef($hFailureUrlParams), HashRef($hCallbackUrlOptions), Object('DE_EPAGES::Presentation::Servlet::Permission'))
                ->thenReturn(FAILURE_URL);

    return $MockifySut->getMockObject();
}

sub _createBasket {
    my $self = shift;
    my ($hAttributes) = @_;

    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Order::API::Object::Basket',
        $hAttributes
    );

    return $Mockify->getMockObject();
}

sub _createLineItemContainer {
    my $self = shift;
    my ($hAttributes) = @_;

    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Order::API::Object::LineItemContainer',
        $hAttributes
    );

    return $Mockify->getMockObject();
}

sub _createLineItemPayment {
    my $self = shift;
    my ($hAttributes) = @_;

    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::AmazonPayments::API::Object::LineItemPaymentAmazonPayments',
        $hAttributes
    );

    $Mockify->addMockWithReturnValueAndParameterCheck('instanceOf', 1, ['string']);
    $Mockify->addMockWithReturnValueAndParameterCheck('confirmOrder', 1, ['string', 'string']);

    return $Mockify->getMockObject();
}

sub _createServlet {
    my $self = shift;
    my ($hAttributes) = @_;

    my $Mockify = DE_EPAGES::Test::Mock::MockifyServlet->new($hAttributes);

    return $Mockify->getMockObject();
}

__PACKAGE__->runScript();