define([
    'testsuite/qunit',
    'testsuite/qunit-fixture!de_epages/appstore/ui/appstore-test',
    'testsuite/sinon',
    'jquery',
    'de_epages/appstore/ui/appstore',
    'ep',

    '$ready!'
], function (QUnit, fixture, sinon, $, de_epages, ep) {

    QUnit.module('de_epages.appstore.ui.appstore', {
        setup: fixture.init,
        teardown: fixture.destroy
    });

    QUnit.asyncTest("widget test presence of methods", function () {

        $.each([
            '_create',
            '_toggleVisibility',
            'destroy'
        ], function (i, fn) {
                QUnit.equal(
                $.isFunction($.ui.appstoreUiAppstore.prototype[fn]),
                true,
                '$.isFunction(' + fn + '):'
            );
        });

        QUnit.start();
    });

    QUnit.asyncTest("widget ui tests", function () {

        var $div = $('.ep-appstore'),
            $toggleLink,
            toggleSpy;

        $div.appstoreUiAppstore({
            translations: {
                hideButton: 'close',
                showButton: 'open'
            }
        });

        setTimeout(function() {
            QUnit.ok(
                $div.data('uiAppstoreUiAppstore') !== undefined,
                'Widget exists'
            );

            // register spy on _toggleVisibility method => number of executions can be investigated
            toggleSpy = sinon.spy($div.data('uiAppstoreUiAppstore'), '_toggleVisibility');

            $div.find('section').each(function(index, section) {
                QUnit.equal(
                    $(section).find('.ep-appstore-list-item:not(.HideElement)').length,
                    2,
                    "Two apps visible for section " + (index + 1) + "."
                );
            });

            // get toggle link
            $toggleLink = $div.find('section.ep-appstore-section-showmore .ep-appstore-section-showmore-toggle');
            QUnit.equal(
                $toggleLink.length,
                1,
                "A toggle link exists."
            );

            // trigger click on toggle link => show hidden apps
            $toggleLink.trigger('click');
            window.setTimeout(function() {
                QUnit.equal(
                    $div.find('section.ep-appstore-section-showmore .ep-appstore-list-item:not(.HideElement)').length,
                    4,
                    "Four apps visible for the second section."
                );
                QUnit.equal(
                    $toggleLink.html(),
                    'close',
                    "Toggle link contains the text 'close'."
                );

                // trigger click on toggle link => hide hidden apps
                $toggleLink.trigger('click');
                window.setTimeout(function() {
                    QUnit.equal(
                        $div.find('section.ep-appstore-section-showmore .ep-appstore-list-item:not(.HideElement)').length,
                        2,
                        "Tow apps visible for the second section."
                    );
                    QUnit.equal(
                        $toggleLink.html(),
                        'open',
                        "Toggle link contains the text 'open'."
                    );

                    QUnit.equal(
                        toggleSpy.callCount,
                        2,
                        'Toggle method was called twice.'
                    );

                    // destroy widget
                    $div.appstoreUiAppstore('destroy');
                    $toggleLink.trigger('click');
                    window.setTimeout(function() {
                        QUnit.equal(
                            toggleSpy.callCount,
                            2,
                            'Toggle method wasn\'t called after destroy => click event removed.'
                        );

                        // restore spies after tests
                        toggleSpy.restore();

                        // start async tests
                        QUnit.start();
                    }, 200);
                }, 200);
            }, 200);
        }, 500);
    });
});