#========================================================================================
# package      DE_EPAGES::Klarna::Hooks::Attribute
# base         -
# state        public
# description  Hook Functions for system attributes
#========================================================================================
package DE_EPAGES::Klarna::Hooks::Attribute;

use strict;
use warnings;
use DE_EPAGES::Object::API::Factory qw(GetRootObjectID LoadObjectByPath);

#========================================================================================
# function     OnGetThirdPartyConfigAttributes
# state        public
#----------------------------------------------------------------------------------------
# syntax        OnGetThirdPartyConfigAttributes($hParams);
#----------------------------------------------------------------------------------------
# description  Funtion adds system attributes of Klarna to $hParams hash reference.
#----------------------------------------------------------------------------------------
# input         $hParams | hash reference of input parameters | hash reference
# return        -
#========================================================================================
sub OnGetThirdPartyConfigAttributes {
    my ($hParams) = @_;

    if ($$hParams{'AttributesCategory'} eq 'Payment') {

        my @Payments = (
                        '/PaymentTypes/KlarnaInvoice',
                        '/PaymentTypes/KlarnaHirePurchase',
                        '/PaymentTypes/KlarnaFinancing',
                       );
        my $RootID = GetRootObjectID();

        foreach my $Payment (@Payments) {
            $Payment = LoadObjectByPath($Payment);
            if (defined $Payment) {
                my $hRow = {
                    'Attributes' => [
                        {'ObjectID' => $Payment->id, 'AttributeAlias' => 'Logging'},
                        {'ObjectID' => $RootID,      'AttributeAlias' => 'KlarnaHostLive'},
                        {'ObjectID' => $RootID,      'AttributeAlias' => 'KlarnaHostTest'},
                        {'ObjectID' => $RootID,      'AttributeAlias' => 'KlarnaRegisterURL'},
                        {'ObjectID' => $RootID,      'AttributeAlias' => 'KlarnaURLAdmin'},
                        {'ObjectID' => $RootID,      'AttributeAlias' => 'KlarnaReservationLinkTest'},
                        {'ObjectID' => $RootID,      'AttributeAlias' => 'KlarnaReservationLinkLive'},
                    ],
                    'SectionID'   => $Payment->get('Alias'),
                    'SectionName' => $Payment->get('NameOrAlias',$$hParams{'LanguageID'}),
                };

                push (@{$$hParams{'Attributes'}},$hRow);
            }
        }
    }

    return;
}

1;
