#========================================================================================
# package      DE_EPAGES::Klarna::t::Recalculate_Internal
# state        public
#----------------------------------------------------------------------------------------
# description  For Klarna Invoice fee
#========================================================================================
package DE_EPAGES::Klarna::t::Recalculate_Internal_NoFee;

use strict;
use DE_EPAGES::Core::API::Error qw ( ExistsError GetError );
use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Database::API::Connection qw ( GetTestSite RunOnStore );
use DE_EPAGES::Object::API::Factory qw (
    ExistsObjectByPath
    LoadObjectByPath
    LoadRootObject
);
use DE_EPAGES::Object::API::XML::ObjectImportHandler qw ( ImportObjects );
use DE_EPAGES::Shop::API::Constants qw ( TAX_MODEL_GROSS );
use Readonly;
use Test::More;

Readonly my $ROOTPATH => '/Test';
Readonly my $SHOPPATH => $ROOTPATH.'/TestShopKlarna';
Readonly my $ORDERPATH_TAX_GROSS_INVOICE_FEE_EMPTY => $SHOPPATH.'/Customers/TestCustomer/Orders/1234-5680';

sub Main {
    RunOnStore(
        'Store' => GetTestSite(),
        'Sub'   => sub {

            # Test
            eval {
                ok( Init(), 'initialization' );
                Test_InvoiceFee_Empty();
            };
            if ( ExistsError() ) {
                my $Error = GetError();
                fail( 'Error: ' . $Error->longMessage );
            }

            # shutDown
            ok( Cleanup(), 'cleanup' );
            done_testing();
        }
    );
}

#----------------------------------------------------------------------------------------
sub Test_InvoiceFee_Empty {
    my $subTestName = (caller(0))[3];
    my $Order = LoadObjectByPath($ORDERPATH_TAX_GROSS_INVOICE_FEE_EMPTY);
    my $LineItemContainer = $Order->get('LineItemContainer');
    my $LineItemPayment = $LineItemContainer->get('Payment');

    my $PaymentLineItemPriceBefore = $Order->get('LineItemContainer')->get('Payment')->get('LineItemPrice');
    is($PaymentLineItemPriceBefore, 1.95, "$subTestName - Klarna LineItemPrice is 1.95 in LineItemPayment");

    $Order->get('LineItemContainer')->recalculate();

    my $PaymentLineItemPrice = $Order->get('LineItemContainer')->get('Payment')->get('LineItemPrice');
    is($PaymentLineItemPrice, 0, "$subTestName - Klarna LineItemPrice is recalculated and changed to 0 in LineItemPayment");
    
    my $hValues = {
        'CurrencyID'=> 'EUR',
        'TaxModel'  => TAX_MODEL_GROSS,
        'Container' => $LineItemContainer
    };

    my $PaymentMethodPrice = $LineItemPayment->get('PaymentMethod')->price($hValues);
    is($PaymentMethodPrice, 0, "$subTestName - Klarna PaymentMethod price is 0 when InvoiceFee is empty");
}

#----------------------------------------------------------------------------------------
sub Cleanup {
    return 1 if $ENV{'SKIP_CLEANUP'};
    LoadObjectByPath($ROOTPATH)->delete if ExistsObjectByPath($ROOTPATH);
    return 1;
}

#----------------------------------------------------------------------------------------
sub Init {
    return 1 if ExistsObjectByPath($ROOTPATH) && $ENV{'SKIP_CLEANUP'};
    Cleanup();
    LoadRootObject()->insertChild( 'Object', { Alias => 'Test' } );
    ImportObjects( 'KlarnaMockShop_NoFee.xml', $ROOTPATH );
    return 1;
}
RunScript( Sub => \&Main );

1;