#========================================================================================
# package      DE_EPAGES::PayPalExpress::t::unit::Webservice_Response
# base         base DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  unit tests for Response
#========================================================================================
package DE_EPAGES::PayPalExpress::t::unit::Webservice_Response;
use base DE_EPAGES::Core::API::Test;
use DE_EPAGES::PayPalExpress::API::Webservice::Response;
use Test::More;
use strict;

sub test {
    my $self = shift;
    $self->test_ValidAddressData();
    $self->test_EmptyRequest();
    done_testing();
}
#----------------------------------------------------------------------------------------
sub test_ValidAddressData {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Response = $self->_buildWebserviceResponseWithValidAddress();

    my $hAddressData = $Response->getAddressData();
    my $hExpectedAddressData = {
        'Street2' => undef,
        'Zipcode' => undef,
        'LastName' => 'FirstName Lastname',
        'Street' => undef,
        'CountryID' => undef,
        'City' => 'Paris',
        'State' => undef,
        'EMail' => 'ich@du.wir',
        'Phone' => '123456789',
    };
    is_deeply( $hAddressData, $hExpectedAddressData, "$SubTestName - tests if we get the address data from the request in epages data structure" );

    return;
}
#----------------------------------------------------------------------------------------
sub test_EmptyRequest {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Response = $self->_buildWebserviceResponseWithEmptyRequest();

    my $hAddressData = $Response->getAddressData();
    my $hExpectedAddressData = {
          'Street2' => undef,
          'Street' => undef,
          'City' => undef,
          'State' => undef,
          'EMail' => undef,
          'Zipcode' => undef,
          'LastName' => undef,
          'CountryID' => undef,
          'Phone' => undef,
        };

    is_deeply($hAddressData, $hExpectedAddressData, "$SubTestName - tests if we get undef for Address if the response is empty");

    return;
}

#----------------------------------------------------------------------------------------
# helpers
#----------------------------------------------------------------------------------------
sub _buildWebserviceResponseWithValidAddress {
    my $self = shift;
    my $WebserviceResponse = {};
    $WebserviceResponse->{'EMAIL'} = 'ich@du.wir';
    $WebserviceResponse->{'PAYMENTREQUEST_0_SHIPTOCITY'} = 'Paris';
    $WebserviceResponse->{'PAYMENTREQUEST_0_SHIPTONAME'} = 'FirstName Lastname';
    $WebserviceResponse->{'PHONENUM'} = '123456789';
    return $self->_createWebserviceResponse($WebserviceResponse);
}
#----------------------------------------------------------------------------------------
sub _buildWebserviceResponseWithEmptyRequest {
    my $self = shift;
    my $WebserviceResponse = {};
    return $self->_createWebserviceResponse($WebserviceResponse);
}
#----------------------------------------------------------------------------------------
sub _createWebserviceResponse {
    my $self = shift;
    my ($hResponseFromPayPal) = @_;
    my $Response = DE_EPAGES::PayPalExpress::API::Webservice::Response->new($hResponseFromPayPal);
    return $Response;
}
#----------------------------------------------------------------------------------------
__PACKAGE__->runScript();