#========================================================================================
# package      DE_EPAGES::Product::Hooks::User
# state        public
# description  hook functions for changing data on user object
#========================================================================================
package DE_EPAGES::Product::Hooks::User;

use strict;
use DE_EPAGES::Core::API::PerlTools qw( ElementOf );

#========================================================================================
# function     OnUserSetPagerEntries
#----------------------------------------------------------------------------------------
# syntax       OnUserSetPagerEntries( $hParams );
#----------------------------------------------------------------------------------------
# description  changes PagerEntries for called ViewActions.
#               (Hook UI_UserSetPagerEntries)
#----------------------------------------------------------------------------------------
# input        $hParams | parameters
#               <ul>
#                   <li>Servlet - servlet - object
#                   <li>PagerViewActionKey - key string for called Class and ViewAction - string
#                   <li>PagerEntriesViewActions - pager entries by Class and ViewActions - ref.hash
#               </ul> | ref.hash.*
#========================================================================================
sub OnUserSetPagerEntries {
    my ($hParams) = @_;

        my $hPagerEntriesViewActions = $hParams->{'PagerEntriesViewActions'};
        my $PagerViewActionKey       = $hParams->{'PagerViewActionKey'};

        my @PageTypesWithSamePagerEntries = ('ProductFolder-UnityMBO-ViewProducts', 'ProductFolder-UnityMBO-SearchProducts');
        return unless ElementOf($PagerViewActionKey, @PageTypesWithSamePagerEntries);

        $hPagerEntriesViewActions->{$_} = $hPagerEntriesViewActions->{$PagerViewActionKey} foreach @PageTypesWithSamePagerEntries;

    return;
}

1;
